@@ -1,6 +1,7 @@
 from django.db import models
 from django.conf import settings
 from django.contrib.auth.models import User
+from django.utils.encoding import python_2_unicode_compatible
 
 from .fields import DNSLabelField
 
@@ -8,6 +9,7 @@ class InstanceManager(models.Manager):
     def for_instance(self, instance):
         return self.get_query_set().filter(instance=instance)
 
+@python_2_unicode_compatible
 class Instance(models.Model):
     label = DNSLabelField( db_index=True, unique=True )
     title = models.CharField( max_length=100 )
@@ -15,7 +17,7 @@ class Instance(models.Model):
     users = models.ManyToManyField(User, related_name='instances', blank=True)
     created_by = models.ForeignKey(User, related_name='created_instances', null=True, blank=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return u'Instance %s' % self.label
 
     def get_absolute_url(self):
@@ -31,4 +33,3 @@ class InstanceMixin(models.Model):
 
     class Meta:
         abstract = True
-
